#[repr(u8)]pub enum Srcinc {
NO_INCREMENT = 0,
WIDTH_X_1 = 1,
WIDTH_X_2 = 2,
WIDTH_X_4 = 3,
}Variants
NO_INCREMENT = 0
No increment. The source address is not incremented for each transfer. This is the usual case when the source is a peripheral device.
WIDTH_X_1 = 1
1 x width. The source address is incremented by the amount specified by Width for each transfer. This is the usual case when the source is memory.
WIDTH_X_2 = 2
2 x width. The source address is incremented by 2 times the amount specified by Width for each transfer.
WIDTH_X_4 = 3
4 x width. The source address is incremented by 4 times the amount specified by Width for each transfer.
Implementations