#[repr(u8)]pub enum Trigpol {
ACTIVE_LOW_FALLING = 0,
ACTIVE_HIGH_RISING = 1,
}Variants
ACTIVE_LOW_FALLING = 0
Active low - falling edge. Hardware trigger is active low or falling edge triggered, based on TRIGTYPE.
ACTIVE_HIGH_RISING = 1
Active high - rising edge. Hardware trigger is active high or rising edge triggered, based on TRIGTYPE.
Implementations